package jp.co.ois.sample.hogeweb;

import java.util.Map;
import java.util.Properties;

import javax.annotation.PostConstruct;

import org.apache.velocity.app.VelocityEngine;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.beans.factory.annotation.Qualifier;
import org.springframework.beans.factory.annotation.Value;
import org.springframework.boot.context.properties.ConfigurationProperties;
import org.springframework.context.annotation.Bean;
import org.springframework.context.annotation.Configuration;
import org.springframework.core.env.MutablePropertySources;
import org.springframework.core.env.PropertySource;
import org.springframework.core.env.StandardEnvironment;
import org.thymeleaf.templateresolver.ClassLoaderTemplateResolver;

import lombok.extern.slf4j.Slf4j;

@Configuration
@Slf4j
public class HogeConfig {

    @Value("${env}")
    String env;

    @Autowired
    StandardEnvironment environment;

    @PostConstruct
    public void init() {
        log.info("env: {}", env);

        MutablePropertySources sources = environment.getPropertySources();
        for (PropertySource<?> p : sources) {
            String name = p.getName();
            Object source = p.getSource();
            if (source instanceof Map) {
                Map<?, ?> map = (Map<?, ?>) source;
                log.debug("{}: {}, {}", name, source.getClass(), map.size());
                for (Map.Entry<?, ?> entry : map.entrySet()) {
                    log.debug("  {}: {}", entry.getKey(), entry.getValue());
                }
            } else {
                log.debug("{}: {}", name, source.getClass());
            }
        }
    }

    @Bean("velocityProperties")
    @ConfigurationProperties(prefix = "mail.velocity")
    public Properties velocityProperties() {
        return new Properties();
    }
    @Bean
    public VelocityEngine velocityEngine(@Qualifier("velocityProperties") Properties props) {
        log.debug("props: {}", props);
        VelocityEngine velocityEngine = new VelocityEngine(props);
        velocityEngine.init();
        return velocityEngine;
    }


    @Bean("thymeleaf-resolver")
    @ConfigurationProperties(prefix = "mail.thymeleaf")
    public ClassLoaderTemplateResolver mailThymeleafResolver() {
        ClassLoaderTemplateResolver templateResolver = new ClassLoaderTemplateResolver();
        return templateResolver;
    }
}
