package jp.co.ois.sample.hogeweb;

import java.io.IOException;
import java.io.StringWriter;
import java.util.Date;
import java.util.Locale;

import org.apache.velocity.Template;
import org.apache.velocity.VelocityContext;
import org.apache.velocity.app.VelocityEngine;
import org.springframework.beans.factory.annotation.Autowired;
import org.springframework.stereotype.Controller;
import org.springframework.ui.Model;
import org.springframework.web.bind.annotation.RequestMapping;
import org.springframework.web.bind.annotation.ResponseBody;
import org.thymeleaf.TemplateEngine;
import org.thymeleaf.context.Context;

import lombok.extern.slf4j.Slf4j;

@Controller
@Slf4j
public class HogeController {

    @RequestMapping(value = "/")
    @ResponseBody
    public String hello() {
        log.debug("called.");
        return "Hello World!";
    }

    @RequestMapping("/hoge")
    public String hoge(Model model) throws IOException {
        log.debug("called.");
        model.addAttribute("hoge", "ほげ");
        return "hoge";
    }


    @Autowired
    VelocityEngine velocityEngine;

    @RequestMapping("/hoge2")
    public String hoge2(Model model) throws IOException {
        log.debug("called.");

        StringWriter writer = new StringWriter();
        VelocityContext ctx = new VelocityContext();
        ctx.put("now", new Date());
        Template template = velocityEngine.getTemplate("mail/hoge.vm");
        template.merge(ctx, writer);
        String body = writer.toString();
        log.debug("body: {}", body);

        model.addAttribute("hoge", body);
        return "hoge";
    }


    @Autowired
    TemplateEngine mailTemplateEngine;

    @RequestMapping("/hoge3")
    public String hoge3(Model model) throws IOException {
        log.debug("called.");

        Context ctx = new Context(Locale.JAPANESE);
        ctx.setVariable("now", new Date());
        String body = mailTemplateEngine.process("hoge-body", ctx);
        log.debug("body: {}", body);

        model.addAttribute("hoge", body);
        return "hoge";
    }

}
